from django.core import urlresolvers
from django.conf import settings
from django_comments.signals import comment_was_posted
from django.conf import settings
import django.db.models

notification = False
if "notification" in settings.INSTALLED_APPS:
    from notification import models as notification
    
friends = False
if "friends" in settings.INSTALLED_APPS:
    friends = True
    from friends.models import Friendship

relationships = False
if "relationships" in settings.INSTALLED_APPS:
    relationships = True


def get_model():
    from unrest_comments.models import UnrestComment
    return UnrestComment

def get_form():
    from unrest_comments.forms import UnrestCommentForm
    return UnrestCommentForm

def get_form_target():
    return urlresolvers.reverse("unrest_comments.views.post_comment")

def comment_callback_for_notification(sender, request=None, comment=None, **kwargs):
    if not notification:
        return
        
    if not comment.is_public and not getattr(settings, 'UNREST_COMMENTS_SEND_NOTICES_FOR_NONPUBLIC', True):
        # If comment is not public and UNREST_COMMENTS_SEND_NOTICES_FOR_NONPUBLIC is False, we don't
        # send the notifications at all.
        return
        
    infodict = {"user": comment.user, "comment": comment, "object": comment.content_object }
        
    if comment.parent:
        # Comment has a parent, we'll use the _replied notices
        notice_type_suffix = "replied"
        infodict["parent_comment"] = comment.parent
        infodict["parent_comment_user"] = comment.parent.user
        
        # Additionnaly, we need to notify the user that posted the comment we
        # are replying to
        if comment.parent.user and comment.parent.user != comment.user:
            notification.send([comment.parent.user], "comment_reply_received", infodict)
        
    else:
        notice_type_suffix = "posted"
        
    # Notifications of stuff I'm doing
    notification.send([comment.user], "comment_%s" % (notice_type_suffix, ), infodict)
    
    # Notifications to my friends and/or my followers, except the author of the
    # parent comment, since he'll receive a separate notice anyway
    if friends:
        notification.send((x['friend'] for x in
            Friendship.objects.friends_for_user(comment.user) if x['friend'] != comment.parent.user),
            "comment_friend_%s" % (notice_type_suffix, ), infodict
        )
    if relationships:
        followers = comment.user.relationships.followers()
        if comment.parent and comment.parent.user:
            followers = followers.exclude(username=comment.parent.user.username)
        notification.send(followers, "comment_friend_%s" % (notice_type_suffix, ), infodict)

comment_was_posted.connect(comment_callback_for_notification)
