from django.contrib import admin
from django.conf import settings
from django_comments import get_model
from django.utils.translation import ugettext_lazy as _
from django_comments.models import Comment
from django_comments.admin import CommentsAdmin
from django.contrib.contenttypes.models import ContentType

class UnrestCommentsAdmin(CommentsAdmin):
    fieldsets = (
        (None,
           {'fields': ('content_type', 'object_pk', 'parent', 'site')}
        ),
        (_('Content'),
           {'fields': ('user', 'comment')}
        ),
        (_('Metadata'),
           {'fields': ('submit_date', 'ip_address', 'is_public', 'is_removed')}
        )
     )

    readonly_fields = ("parent","content_type","object_pk","user","site","submit_date")
    list_display = ('user', 'getobject', 'level', 'submit_date')
    list_filter = ('submit_date', 'is_public', 'is_removed')
    date_hierarchy = None
    list_per_page = 40
    ordering = ('-submit_date',)
    search_fields = ('comment', 'user__username', 'user_name', 'user_email', 'user_url', 'ip_address')

    def not_is_removed(self, obj):
        return not obj.is_removed
    not_is_removed.boolean = True
    not_is_removed.short_description = _('Not removed')

    def getobject(self, obj):
        try:
            object_type = ContentType.objects.get(model=str(obj.content_type))
            o = object_type.get_object_for_this_type(pk=str(obj.object_pk))
        except:
            o = u"%s : %s" % (obj.content_type, obj.object_pk)
        return o
    getobject.short_description = _('Object')

try:
  admin.site.unregister(Comment)
except:
  pass
admin.site.register(get_model(), UnrestCommentsAdmin)
